@@ -1,11 +1,11 @@
 // Copyright (C) 2022 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
+#include <QtCore/qglobal.h>
+
 #ifndef QTMULTIMEDIAEXPORTS_H
 #define QTMULTIMEDIAEXPORTS_H
 
-#include <QtCore/qglobal.h>
-
 #if defined(QT_SHARED) || !defined(QT_STATIC)
 #  if defined(QT_BUILD_MULTIMEDIA_LIB)
 #    define Q_MULTIMEDIA_EXPORT Q_DECL_EXPORT
@@ -16,8 +16,9 @@
 #  define Q_MULTIMEDIA_EXPORT
 #endif
 
-#if !defined(QT_BUILD_MULTIMEDIA_LIB) || defined(QT_STATIC)
+#if !defined(QT_BUILD_MULTIMEDIA_LIB) && !defined(QT_STATIC)
 /* outside library → inline decl + defi */
+/* static builds treat everything as part of the library, so they never inline */
 #  define QT_MULTIMEDIA_INLINE_SINCE(major, minor) inline
 #  define QT_MULTIMEDIA_INLINE_IMPL_SINCE(major, minor) 1
 #elif defined(QT_MULTIMEDIA_BUILD_REMOVED_API)
